@@ -4,8 +4,9 @@ from .processors import (
     StringProcessor,
     JsonProcessor,
     JsonLineProcessor,
+    JsonListProcessor,
     MsgpackProcessor,
 )
 from .serializers import StringSerializer, JsonSerializer, MsgpackSerializer
 from .checkpointers import MemoryCheckPointer, RedisCheckPointer
-from .aggregators import SimpleAggregator, NewlineAggregator, NetstringAggregator
+from .aggregators import SimpleAggregator, NewlineAggregator, NetstringAggregator, ListAggregator
